darkhistory.spec.transferfunclist.TransferFuncInterp
====================================================

.. currentmodule:: darkhistory.spec.transferfunclist

.. autoclass:: TransferFuncInterp

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TransferFuncInterp.__init__
      ~TransferFuncInterp.get_tf
   
   

   
   
   